import { createFilter, dataToEsm } from '@rollup/pluginutils';
import jsToml from '@ltd/j-toml';

function toml(options) {
  if ( options === void 0 ) options = {};

  var filter = createFilter(options.include, options.exclude);
  var indent = 'indent' in options ? options.indent : '\t';

  return {
    name: 'toml',

    // eslint-disable-next-line no-shadow
    transform: function transform(tomlSrc, id) {
      if (id.slice(-5) !== '.toml' || !filter(id)) { return null; }

      try {
        var parsed = jsToml.parse(tomlSrc, { bigint: false });
        return {
          code: dataToEsm(parsed, {
            preferConst: options.preferConst,
            compact: options.compact,
            namedExports: options.namedExports,
            indent: indent
          }),
          map: { mappings: '' }
        };
      } catch (err) {
        var message = 'Could not parse TOML file';
        // TODO : find the real position
        var position = 1;
        this.warn({ message: message, id: id, position: position });
        return null;
      }
    }
  };
}

export { toml as default };
//# sourceMappingURL=index.es.js.map
